@@ -1,15 +1,17 @@
 /*
  * Copyright (C) 2012, 2013  Free Software Foundation, Inc.
  *
- * This is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This file is part of GNU lightning.
  *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU lightning is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published
+ * by the Free Software Foundation; either version 3, or (at your option)
+ * any later version.
+ *
+ * GNU lightning is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+ * License for more details.
  *
  * Authors:
  *	Paulo Cesar Pereira de Andrade
@@ -56,9 +58,6 @@ typedef enum {
     _R14,			/* lr - link register */
     _R15,			/* pc - program counter */
 #define JIT_RA0			_R0
-#define JIT_RA1			_R1
-#define JIT_RA2			_R2
-#define JIT_RA3			_R3
     _R3,			/* r3 - argument/result */
     _R2,			/* r2 - argument/result */
     _R1,			/* r1 - argument/result */
@@ -69,8 +68,6 @@ typedef enum {
 #define JIT_F3			(jit_hardfp_p() ? _D11 : _D3)
 #define JIT_F4			(jit_hardfp_p() ? _D12 : _D4)
 #define JIT_F5			(jit_hardfp_p() ? _D13 : _D5)
-#define JIT_F6			(jit_hardfp_p() ? _D14 : _D6)
-#define JIT_F7			(jit_hardfp_p() ? _D15 : _D7)
     _S16,	_D8 = _S16,	_Q4 = _D8,
     _S17,
     _S18,	_D9 = _S18,
@@ -88,13 +85,6 @@ typedef enum {
     _S30,	_D15 = _S30,
     _S31,
 #define JIT_FA0			_D0
-#define JIT_FA1			_D1
-#define JIT_FA2			_D2
-#define JIT_FA3			_D3
-#define JIT_FA4			_D4
-#define JIT_FA5			_D5
-#define JIT_FA6			_D6
-#define JIT_FA7			_D7
     _S15,
     _S14,	_D7 = _S14,
     _S13,
