@@ -1,15 +1,17 @@
 /*
  * Copyright (C) 2012, 2013  Free Software Foundation, Inc.
  *
- * This is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This file is part of GNU lightning.
  *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU lightning is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published
+ * by the Free Software Foundation; either version 3, or (at your option)
+ * any later version.
+ *
+ * GNU lightning is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+ * License for more details.
  *
  * Authors:
  *	Paulo Cesar Pereira de Andrade
@@ -28,7 +30,7 @@ typedef enum {
 #define jit_arg_reg_p(i)	((i) >= 0 && (i) < 8)
 #define jit_r(i)		(_R11 + (i))
 #define jit_r_num()		3
-#if __WORDSIZE == 32
+#if __ppc__
 #  define jit_v(i)		(_R30 - (i))
 #  define jit_v_num()		17
 #else
@@ -39,7 +41,7 @@ typedef enum {
 #define jit_f(i)		(_F14 + (i))
 #define jit_f_num()		6
     _R0,
-#if __WORDSIZE == 32
+#if __ppc__
 #  define JIT_R0		_R11
 #  define JIT_R1		_R12
 #  define JIT_R2		_R13
@@ -63,7 +65,7 @@ typedef enum {
 #define JIT_V11			jit_v(11)
 #define JIT_V12			jit_v(12)
 #define JIT_V13			jit_v(13)
-#if __WORDSIZE == 32
+#if __ppc__
 #  define JIT_V14		jit_v(14)
 #  define JIT_V15		jit_v(15)
 #  define JIT_V16		jit_v(16)
