@@ -1,15 +1,17 @@
 /*
  * Copyright (C) 2013  Free Software Foundation, Inc.
  *
- * This is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This file is part of GNU lightning.
  *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU lightning is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published
+ * by the Free Software Foundation; either version 3, or (at your option)
+ * any later version.
+ *
+ * GNU lightning is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+ * License for more details.
  *
  * Authors:
  *	Paulo Cesar Pereira de Andrade
@@ -686,7 +688,7 @@ _f2r(jit_state_t *_jit,
     v.rd.b    = rd;
     v.op2.b   = op2;
     v.imm22.b = imm22;
-    ii(v.v);    
+    ii(v.v);
 }
 
 static void
@@ -705,7 +707,7 @@ _f2b(jit_state_t *_jit,
     v.cond.b   = cond;
     v.op2.b    = op2;
     v.disp22.b = disp22;
-    ii(v.v);    
+    ii(v.v);
 }
 
 static void
@@ -725,7 +727,7 @@ _f3r(jit_state_t *_jit, jit_int32_t op, jit_int32_t rd,
     v.i.b     = 0;
     v.asi.b   = 0;
     v.rs2.b   = rs2;
-    ii(v.v);    
+    ii(v.v);
 }
 
 static void
@@ -744,7 +746,7 @@ _f3i(jit_state_t *_jit, jit_int32_t op, jit_int32_t rd,
     v.rs1.b    = rs1;
     v.i.b      = 1;
     v.simm13.b = simm13;
-    ii(v.v);    
+    ii(v.v);
 }
 
 static void
@@ -769,7 +771,7 @@ _f3t(jit_state_t *_jit, jit_int32_t cond,
 	v.asi.b = 0;
 	v.rs2.b = rs2_imm7;
     }
-    ii(v.v);    
+    ii(v.v);
 }
 
 static void
@@ -790,7 +792,7 @@ _f3a(jit_state_t *_jit, jit_int32_t op, jit_int32_t rd,
     v.i.b     = 0;
     v.asi.b   = asi;
     v.rs2.b   = rs2;
-    ii(v.v);    
+    ii(v.v);
 }
 
 static void
@@ -801,7 +803,7 @@ _f1(jit_state_t *_jit, jit_int32_t op, jit_int32_t disp30)
     assert(s30_p(disp30));
     v.op.b     = op;
     v.disp30.b = disp30;
-    ii(v.v);    
+    ii(v.v);
 }
 
 static void
@@ -1562,7 +1564,7 @@ _jmpi(jit_state_t *_jit, jit_word_t i0)
 {
     jit_word_t		w;
     jit_int32_t		reg;
-    w = (i0 - w) >> 2;
+    w = (i0 - _jit->pc.w) >> 2;
     if (s22_p(w)) {
 	BA(w);
 	NOP();
