@@ -1,15 +1,17 @@
 /*
  * Copyright (C) 2013  Free Software Foundation, Inc.
  *
- * This is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This file is part of GNU lightning.
  *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU lightning is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published
+ * by the Free Software Foundation; either version 3, or (at your option)
+ * any later version.
+ *
+ * GNU lightning is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+ * License for more details.
  *
  * Authors:
  *	Paulo Cesar Pereira de Andrade
@@ -372,8 +374,10 @@ _jit_getarg_d(jit_state_t *_jit, jit_int32_t u, jit_node_t *v)
 	jit_ldxi_f(u, JIT_FP, -8);
 	jit_ldxi_f(u + 1, JIT_FP, stack_framesize);
     }
-    else
-	jit_ldxi_d(u, JIT_FP, v->u.w);
+    else {
+	jit_ldxi_f(u, JIT_FP, v->u.w);
+	jit_ldxi_f(u + 1, JIT_FP, v->u.w + 4);
+    }
 }
 
 void
@@ -455,7 +459,10 @@ _jit_pushargr_d(jit_state_t *_jit, jit_int32_t u)
 	_jitc->function->call.size += sizeof(jit_float32_t);
     }
     else {
-	jit_stxi_d(_jitc->function->call.size + stack_framesize, JIT_SP, u);
+	jit_stxi_f(_jitc->function->call.size + stack_framesize,
+		   JIT_SP, u);
+	jit_stxi_f(_jitc->function->call.size + stack_framesize + 4,
+		   JIT_SP, u + 1);
 	_jitc->function->call.size += sizeof(jit_float64_t);
     }
 }
@@ -480,7 +487,10 @@ _jit_pushargi_d(jit_state_t *_jit, jit_float64_t u)
 	_jitc->function->call.size += sizeof(jit_float32_t);
     }
     else {
-	jit_stxi_d(_jitc->function->call.size + stack_framesize, JIT_SP, regno);
+	jit_stxi_f(_jitc->function->call.size + stack_framesize,
+		   JIT_SP, regno);
+	jit_stxi_f(_jitc->function->call.size + stack_framesize + 4,
+		   JIT_SP, regno + 1);
 	_jitc->function->call.size += sizeof(jit_float64_t);
     }
     jit_unget_reg(regno);
