@@ -1,15 +1,17 @@
 /*
  * Copyright (C) 2012, 2013  Free Software Foundation, Inc.
  *
- * This is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This file is part of GNU lightning.
  *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU lightning is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published
+ * by the Free Software Foundation; either version 3, or (at your option)
+ * any later version.
+ *
+ * GNU lightning is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+ * License for more details.
  *
  * Authors:
  *	Paulo Cesar Pereira de Andrade
@@ -18,6 +20,16 @@
 #include <lightning.h>
 #include <lightning/jit_private.h>
 #include <sys/mman.h>
+#if defined(__sgi)
+#  include <fcntl.h>
+#endif
+
+#ifndef MAP_ANON
+#  define MAP_ANON			MAP_ANONYMOUS
+#  ifndef MAP_ANONYMOUS
+#    define MAP_ANONYMOUS		0
+#  endif
+#endif
 
 #define jit_regload_reload		0	/* convert to reload */
 #define jit_regload_delete		1	/* just remove node */
@@ -155,6 +167,9 @@ _patch_register(jit_state_t *jit, jit_node_t *node, jit_node_t *link,
  * Initialization
  */
 const char	*jit_progname;
+#if !defined(__sgi)
+#define  mmap_fd			-1
+#endif
 
 /*
  * Implementation
@@ -1371,6 +1386,9 @@ _jit_optimize(jit_state_t *_jit)
     jit_node_t		*node;
     jit_block_t		*block;
     jit_word_t		 offset;
+#if defined(__sgi)
+    int			 mmap_fd;
+#endif
 
     _jitc->function = NULL;
 
@@ -1487,10 +1505,16 @@ _jit_optimize(jit_state_t *_jit)
     _jit->data.length = (_jitc->data.offset +
 			 /* reserve space for annotations */
 			 _jitc->note.size + 4095) & -4096;
+#if defined(__sgi)
+    mmap_fd = open("/dev/zero", O_RDWR);
+#endif
     ptr = mmap(NULL, _jit->data.length,
 	       PROT_READ | PROT_WRITE,
-	       MAP_PRIVATE | MAP_ANON, -1, 0);
+	       MAP_PRIVATE | MAP_ANON, mmap_fd, 0);
     assert(ptr != MAP_FAILED);
+#if defined(__sgi)
+    close(mmap_fd);
+#endif
     memcpy(ptr, _jit->data.ptr, _jitc->data.offset);
     jit_free((jit_pointer_t *)&_jit->data.ptr);
     _jit->data.ptr = ptr;
@@ -1644,6 +1668,9 @@ _jit_emit(jit_state_t *_jit)
     jit_node_t		*node;
     size_t		 length;
     int			 result;
+#if defined(__sgi)
+    int			 mmap_fd;
+#endif
 
     if (_jitc->function)
 	jit_epilog();
@@ -1656,9 +1683,12 @@ _jit_emit(jit_state_t *_jit)
 
     _jit->code.length = _jitc->pool.length * 1024 * _jitc->mult;
 
+#if defined(__sgi)
+    mmap_fd = open("/dev/zero", O_RDWR);
+#endif
     _jit->code.ptr = mmap(NULL, _jit->code.length,
 			  PROT_EXEC | PROT_READ | PROT_WRITE,
-			  MAP_PRIVATE | MAP_ANON, -1, 0);
+			  MAP_PRIVATE | MAP_ANON, mmap_fd, 0);
     assert(_jit->code.ptr != MAP_FAILED);
     _jitc->code.end = _jit->code.ptr + _jit->code.length - 64;
     _jit->pc.uc = _jit->code.ptr;
@@ -1684,7 +1714,7 @@ _jit_emit(jit_state_t *_jit)
 #else
 	    _jit->code.ptr = mmap(NULL, length,
 				  PROT_EXEC | PROT_READ | PROT_WRITE,
-				  MAP_PRIVATE | MAP_ANON, -1, 0);
+				  MAP_PRIVATE | MAP_ANON, mmap_fd, 0);
 #endif
 
 	    assert(_jit->code.ptr != MAP_FAILED);
@@ -1697,6 +1727,10 @@ _jit_emit(jit_state_t *_jit)
 	    break;
     }
 
+#if defined(__sgi)
+    close(mmap_fd);
+#endif
+
     _jitc->done = 1;
     jit_annotate();
 
@@ -2879,4 +2913,8 @@ _patch_register(jit_state_t *_jit, jit_node_t *node, jit_node_t *link,
 #  include "jit_ia64.c"
 #elif defined(__hppa__)
 #  include "jit_hppa.c"
+#elif defined(__aarch64__)
+#  include "jit_aarch64.c"
+#elif defined(__s390x__)
+#  include "jit_s390x.c"
 #endif
