@@ -36,7 +36,7 @@ def load_requirements(
     >>> from lightning.app import _PROJECT_ROOT
     >>> path_req = os.path.join(_PROJECT_ROOT, "requirements")
     >>> load_requirements(path_req, "docs.txt")  # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE +SKIP
-    ['sphinx>=4.0', ...]  # TODO: remove SKIP, fails on python 3.7
+    ['sphinx>=4.0', ...]
     """
     path = os.path.join(path_dir, file_name)
     if not os.path.isfile(path):
@@ -196,7 +196,7 @@ class BuildConfig:
         return {"__build_config__": asdict(self)}
 
     @classmethod
-    def from_dict(cls, d: Dict) -> Self:  # type: ignore[valid-type]
+    def from_dict(cls, d: Dict) -> Self:
         return cls(**d["__build_config__"])
 
 
