@@ -28,7 +28,7 @@ from lightning.fabric.utilities.types import _TORCH_LRSCHEDULER
 from lightning.pytorch import Callback, LightningDataModule, LightningModule, seed_everything, Trainer
 from lightning.pytorch.utilities.exceptions import MisconfigurationException
 from lightning.pytorch.utilities.model_helpers import is_overridden
-from lightning.pytorch.utilities.rank_zero import rank_zero_deprecation, rank_zero_warn
+from lightning.pytorch.utilities.rank_zero import rank_zero_warn
 
 _JSONARGPARSE_SIGNATURES_AVAILABLE = RequirementCache("jsonargparse[signatures]>=4.17.0")
 
@@ -279,7 +279,6 @@ class LightningCLI:
         args: ArgsType = None,
         run: bool = True,
         auto_configure_optimizers: bool = True,
-        **kwargs: Any,  # Remove with deprecations of v2.0.0
     ) -> None:
         """Receives as input pytorch-lightning classes (or callables which return pytorch-lightning classes), which
         are called / instantiated using a parsed configuration file and / or command line args.
@@ -290,8 +289,6 @@ class LightningCLI:
 
         For more info, read :ref:`the CLI docs <lightning-cli>`.
 
-        .. warning:: ``LightningCLI`` is in beta and subject to change.
-
         Args:
             model_class: An optional :class:`~lightning.pytorch.core.module.LightningModule` class to train on or a
                 callable which returns a :class:`~lightning.pytorch.core.module.LightningModule` instance when
@@ -331,8 +328,6 @@ class LightningCLI:
         self.parser_kwargs = parser_kwargs or {}  # type: ignore[var-annotated]  # github.com/python/mypy/issues/6463
         self.auto_configure_optimizers = auto_configure_optimizers
 
-        self._handle_deprecated_params(kwargs)
-
         self.model_class = model_class
         # used to differentiate between the original value and the processed value
         self._model_class = model_class or LightningModule
@@ -357,28 +352,6 @@ class LightningCLI:
         if self.subcommand is not None:
             self._run_subcommand(self.subcommand)
 
-    def _handle_deprecated_params(self, kwargs: dict) -> None:
-        for name in kwargs.keys() & ["save_config_filename", "save_config_overwrite", "save_config_multifile"]:
-            value = kwargs.pop(name)
-            key = name.replace("save_config_", "").replace("filename", "config_filename")
-            self.save_config_kwargs[key] = value
-            rank_zero_deprecation(
-                f"LightningCLI's {name!r} init parameter is deprecated from v1.8 and will "
-                f"be removed in v2.0.0. Use `save_config_kwargs={{'{key}': ...}}` instead."
-            )
-
-        for name in kwargs.keys() & ["description", "env_prefix", "env_parse"]:
-            value = kwargs.pop(name)
-            key = name.replace("env_parse", "default_env")
-            self.parser_kwargs[key] = value
-            rank_zero_deprecation(
-                f"LightningCLI's {name!r} init parameter is deprecated from v1.9 and will "
-                f"be removed in v2.0. Use `parser_kwargs={{'{key}': ...}}` instead."
-            )
-
-        if kwargs:
-            raise ValueError(f"Unexpected keyword parameters: {kwargs}")
-
     def _setup_parser_kwargs(self, parser_kwargs: Dict[str, Any]) -> Tuple[Dict[str, Any], Dict[str, Any]]:
         subcommand_names = self.subcommands().keys()
         main_kwargs = {k: v for k, v in parser_kwargs.items() if k not in subcommand_names}
@@ -461,7 +434,6 @@ class LightningCLI:
             "validate": {"model", "dataloaders", "datamodule"},
             "test": {"model", "dataloaders", "datamodule"},
             "predict": {"model", "dataloaders", "datamodule"},
-            "tune": {"model", "train_dataloaders", "val_dataloaders", "datamodule"},
         }
 
     def _add_subcommands(self, parser: LightningArgumentParser, **kwargs: Any) -> None:
@@ -509,9 +481,9 @@ class LightningCLI:
     def parse_arguments(self, parser: LightningArgumentParser, args: ArgsType) -> None:
         """Parses command line arguments and stores it in ``self.config``."""
         if args is not None and len(sys.argv) > 1:
-            raise ValueError(
+            rank_zero_warn(
                 "LightningCLI's args parameter is intended to run from within Python like if it were from the command "
-                "line. To prevent mistakes it is not allowed to provide both args and command line arguments, got: "
+                "line. To prevent mistakes it is not recommended to provide both args and command line arguments, got: "
                 f"sys.argv[1:]={sys.argv[1:]}, args={args}."
             )
         if isinstance(args, (dict, Namespace)):
