@@ -22,7 +22,6 @@ from lightning.fabric.accelerators.tpu import _XLA_AVAILABLE
 from lightning.fabric.strategies.launchers.xla import _rank_teardown
 from lightning.fabric.utilities import move_data_to_device
 from lightning.pytorch.strategies.launchers.multiprocessing import (
-    _FakeQueue,
     _GlobalStateSnapshot,
     _MultiProcessingLauncher,
     _WorkerOutput,
@@ -47,7 +46,7 @@ class _XLALauncher(_MultiProcessingLauncher):
         strategy: A reference to the strategy that is used together with this launcher
     """
 
-    def __init__(self, strategy: "pl.strategies.TPUSpawnStrategy") -> None:
+    def __init__(self, strategy: "pl.strategies.XLAStrategy") -> None:
         if not _XLA_AVAILABLE:
             raise ModuleNotFoundError(str(_XLA_AVAILABLE))
         super().__init__(strategy=strategy, start_method="fork")
@@ -73,12 +72,19 @@ class _XLALauncher(_MultiProcessingLauncher):
         return_queue = context.SimpleQueue()
         import torch_xla.distributed.xla_multiprocessing as xmp
 
-        xmp.spawn(
+        process_context = xmp.spawn(
             self._wrapping_function,
             args=(trainer, function, args, kwargs, return_queue),
             nprocs=self._strategy.num_processes,
             start_method=self._start_method,
+            join=False,  # we will join ourselves to get the process references
         )
+        # xla will not actually create processes if only 1 device
+        if process_context is not None:
+            self.procs = process_context.processes
+            while not process_context.join():
+                pass
+
         worker_output = return_queue.get()
         if trainer is None:
             return worker_output
@@ -130,8 +136,7 @@ class _XLALauncher(_MultiProcessingLauncher):
         if self._strategy.local_rank != 0:
             return None
 
-        # adds the `callback_metrics` to the queue
-        extra = _FakeQueue()
-        self.add_to_queue(trainer, extra)
+        # add extra result data from trainer to send to main process
+        extra = self.get_extra_results(trainer)
 
         return _WorkerOutput(best_model_path, weights_path, trainer.state, results, extra)
